import { jsx as _jsx } from "react/jsx-runtime";
import { createContext, useContext } from "react";
import { useScrollSpy } from "./useScrollSpy";
/**
 * @param ScrollSpyParams Optional params
 * @param ScrollSpyParams.offsetPx Distance from Y coordinate of the base (px)
 * @param ScrollSpyParams.throttleMs Interval of update processing (ms)
 * @returns [ ScrollSpyProvider, useScrollSpyContext ] - Two return values are returned as an array
 * @returns ScrollSpyProvider - This Provider components provides useScrollSpy return value descendants of this Provider
 * @returns useScrollSpyContext - Function is
 */
export const createScrollSpyContext = ({ offsetPx = 0, throttleMs = 100, } = {}) => {
    const [activeEntry, actions] = useScrollSpy({ offsetPx, throttleMs });
    const ScrollSpyContext = createContext({
        activeEntry,
        actions,
    });
    const Provider = ({ children }) => {
        return (_jsx(ScrollSpyContext.Provider, Object.assign({ value: { activeEntry, actions } }, { children: children }), void 0));
    };
    const getActiveEntry = () => useContext(ScrollSpyContext).activeEntry;
    const getActions = () => useContext(ScrollSpyContext).actions;
    return { Provider, getActiveEntry, getActions };
};
//# sourceMappingURL=createScrollSpyContext.js.map